"""Module implementing raw communication with the WhyHow API.

All the classes here will be subject to the OpenAPI schema validation test.
All the functions here will be directly useable inside the whyhow_api/resources.
"""

from whyhow.raw.chunks.requests import (
    aget_all_chunks,
    aget_chunk,
    get_all_chunks,
    get_chunk,
)
from whyhow.raw.chunks.schemas import (
    ChunkDocumentDetailRaw,
    ChunkMetadataRaw,
    ChunkRaw,
    ChunkWorkspaceRaw,
    GetAllChunksResponseBody,
    GetChunkResponseBody,
)
from whyhow.raw.documents.requests import (
    adelete_document,
    agenerate_presigned_document,
    aget_all_documents,
    aget_document,
    aprocess_document,
    delete_document,
    generate_presigned_document,
    get_all_documents,
    get_document,
    process_document,
)
from whyhow.raw.documents.schemas import (
    DeleteDocumentResponseBody,
    DocumentMetadataRaw,
    DocumentProcessingDetailsRaw,
    DocumentRaw,
    DocumentSlimRaw,
    DocumentWorkspaceRaw,
    GeneratePresignedDocumentRequestBody,
    GeneratePresignedDocumentResponseBody,
    GetAllDocumentsResponseBody,
    GetDocumentResponseBody,
    ProcessDocumentResponseBody,
)
from whyhow.raw.graphs.requests import (
    acreate_graph,
    aexport_graph_cypher,
    aget_all_graphs,
    aget_all_triples,
    aget_graph,
    aquery_graph_structured,
    aquery_graph_unstructured,
    aupdate_graph,
    create_graph,
    export_graph_cypher,
    get_all_graphs,
    get_all_triples,
    get_graph,
    query_graph_structured,
    query_graph_unstructured,
    update_graph,
)
from whyhow.raw.graphs.schemas import (
    CreateGraphRequestBody,
    CreateGraphResponseBody,
    ExportGraphCypherResponseBody,
    GetAllGraphsResponseBody,
    GetGraphResponseBody,
    GetGraphTriplesResponseBody,
    GraphChunkFiltersRaw,
    GraphNameRaw,
    GraphQueryRaw,
    QueryGraphRequestBody,
    QueryGraphResponseBody,
    UpdateGraphRequestBody,
    UpdateGraphResponseBody,
)
from whyhow.raw.schemas.requests import (
    acreate_schema,
    adelete_schema,
    agenerate_schema,
    aget_all_schemas,
    aget_schema,
    create_schema,
    delete_schema,
    generate_schema,
    get_all_schemas,
    get_schema,
)
from whyhow.raw.schemas.schemas import (
    CreateSchemaRequestBody,
    CreateSchemaResponseBody,
    DeleteSchemaResponseBody,
    GenerateSchemaRequestBody,
    GenerateSchemaResponseBody,
    GetAllSchemasResponseBody,
    GetSchemaResponseBody,
    SchemaEntityFieldRaw,
    SchemaEntityRaw,
    SchemaGeneratedRaw,
    SchemaRaw,
    SchemaRelationRaw,
    SchemaSlimRaw,
    SchemaTriplePatternRaw,
    SchemaTriplePatternSlimRaw,
    SchemaWorkspaceRaw,
)
from whyhow.raw.workspaces.requests import (
    acreate_workspace,
    adelete_workspace,
    aget_all_workspaces,
    aget_workspace,
    aupdate_workspace,
    create_workspace,
    delete_workspace,
    get_all_workspaces,
    get_workspace,
    update_workspace,
)
from whyhow.raw.workspaces.schemas import (
    CreateWorkspaceRequestBody,
    CreateWorkspaceResponseBody,
    DeleteWorkspaceResponseBody,
    GetAllWorkspacesResponseBody,
    GetWorkspaceResponseBody,
    UpdateWorkspaceRequestBody,
    UpdateWorkspaceResponseBody,
    WorkspaceRaw,
)

__all__ = [
    "ChunkDocumentDetailRaw",
    "ChunkMetadataRaw",
    "ChunkRaw",
    "ChunkWorkspaceRaw",
    "CreateGraphRequestBody",
    "CreateGraphResponseBody",
    "CreateSchemaRequestBody",
    "CreateSchemaResponseBody",
    "CreateWorkspaceRequestBody",
    "CreateWorkspaceResponseBody",
    "DeleteDocumentResponseBody",
    "DeleteSchemaResponseBody",
    "DeleteWorkspaceResponseBody",
    "DocumentMetadataRaw",
    "DocumentProcessingDetailsRaw",
    "DocumentRaw",
    "DocumentSlimRaw",
    "DocumentWorkspaceRaw",
    "ExportGraphCypherResponseBody",
    "GeneratePresignedDocumentRequestBody",
    "GeneratePresignedDocumentResponseBody",
    "GenerateSchemaRequestBody",
    "GenerateSchemaResponseBody",
    "GetAllChunksResponseBody",
    "GetAllDocumentsResponseBody",
    "GetAllGraphsResponseBody",
    "GetAllSchemasResponseBody",
    "GetAllWorkspacesResponseBody",
    "GetChunkResponseBody",
    "GetDocumentResponseBody",
    "GetGraphResponseBody",
    "GetGraphTriplesResponseBody",
    "GetSchemaResponseBody",
    "GetWorkspaceResponseBody",
    "GraphChunkFiltersRaw",
    "GraphNameRaw",
    "GraphQueryRaw",
    "ProcessDocumentResponseBody",
    "QueryGraphRequestBody",
    "QueryGraphResponseBody",
    "SchemaEntityFieldRaw",
    "SchemaEntityRaw",
    "SchemaGeneratedRaw",
    "SchemaRaw",
    "SchemaSlimRaw",
    "SchemaRelationRaw",
    "SchemaTriplePatternRaw",
    "SchemaTriplePatternSlimRaw",
    "SchemaWorkspaceRaw",
    "UpdateGraphRequestBody",
    "UpdateGraphResponseBody",
    "UpdateWorkspaceRequestBody",
    "UpdateWorkspaceResponseBody",
    "WorkspaceRaw",
    "acreate_graph",
    "acreate_schema",
    "acreate_workspace",
    "adelete_document",
    "adelete_schema",
    "adelete_workspace",
    "agenerate_presigned_document",
    "agenerate_schema",
    "aget_all_chunks",
    "aget_all_documents",
    "aget_all_graphs",
    "aget_all_schemas",
    "aget_all_triples",
    "aget_all_workspaces",
    "aget_chunk",
    "aget_document",
    "aget_graph",
    "aget_schema",
    "aget_workspace",
    "aexport_graph_cypher",
    "aprocess_document",
    "aquery_graph_structured",
    "aquery_graph_unstructured",
    "aupdate_graph",
    "aupdate_workspace",
    "create_graph",
    "create_schema",
    "create_workspace",
    "delete_document",
    "delete_schema",
    "delete_workspace",
    "export_graph_cypher",
    "generate_presigned_document",
    "generate_schema",
    "get_all_chunks",
    "get_all_documents",
    "get_all_graphs",
    "get_all_schemas",
    "get_all_triples",
    "get_all_workspaces",
    "get_chunk",
    "get_document",
    "get_graph",
    "get_schema",
    "get_workspace",
    "process_document",
    "query_graph_structured",
    "query_graph_unstructured",
    "update_graph",
    "update_workspace",
]
